var deviceID = '';

var TuioCanvas = {
    init: function() {
        this.Main.init();
    }
};

TuioCanvas.Main = (function() {
    var client = null,
    screenW = null,
    screenH = null,
    time = null,
    canvas = null,
    context = null,
    objSize = 50,

    init = function() {
        screenW = $(window).innerWidth();
        screenH = $(window).innerHeight();
        time = new Date().getTime();
        canvas = $("#tuioCanvas").get(0);
        canvas.width = screenW;
        canvas.height = screenH;
        context = canvas.getContext("2d");

        initClient();
    },

    initClient = function() {
        client = new Tuio.Client({
            host: "http://localhost:5000"
        });
        client.on("connect", onConnect);
        client.connect();
    },

    onConnect = function() {
        draw();
    },

    draw = function() {
        requestAnimationFrame(draw);

        context.fillStyle = "#ffffff";
        context.fillRect(0, 0, canvas.width, canvas.height);

        var cursors = client.getTuioCursors(),
        objects = client.getTuioObjects();

        for (var i in cursors) {
            drawCursor(cursors[i]);
        }

        for (var i in objects) {
            drawObject(objects[i]);
        }
    },

    drawCursor = function(cursor) {
        context.fillStyle = "#009fe3";
        context.beginPath();
        context.arc(
            cursor.getScreenX(screenW),
            cursor.getScreenY(screenH),
            objSize * 0.5,
            0,
            Math.PI * 2
        );
        context.closePath();
        context.fill();
    },

	// Images
    drawObject = function(object) {
        context.save();
		calibration();
		//var getCalXY = calibration();
		//document.getElementById('message').innerHTML = 'x: ' + object.getX() + ', y: ' + object.getY();
		
        context.translate(
            object.getScreenX(screenW) + objSize * 0.5,
            object.getScreenY(screenH) + objSize * 0.5
        );
        context.rotate(object.getAngle());
		
		deviceID = '' + object.symbolId;

        context.fillStyle = "black";
        context.fillRect(-objSize * 0.5, -objSize * 0.5, objSize, objSize);
		context.fillStyle = "red";
		context.font = "18pt Arial";
		context.fillText(deviceID, -objSize * 0.1, -objSize * 0.1);
        context.restore();
		
		var off = document.getElementById(deviceID).offsetWidth;
		
		document.getElementById(deviceID).style.left = object.getScreenX(screenW) - ((off * 0.5) - (objSize * 0.5))  + 'px' ;
		document.getElementById(deviceID).style.top = object.getScreenY(screenH) + objSize + 'px';
		//document.getElementById(deviceID).style.transform = 'rotate(' + object.getAngle() + 'deg)';
    };
	
	/*
	function showImage(src, width, height, posX, posY) {
	var myCanvas = document.getElementById("tuioCanvas");
	var ctx = myCanvas.getContext("2d");
	posX = posX * 900;
    posY = posY * 500;
	
	var img = new Image();
    img.src = src;
	img.draggable="true";
	img.ondragstart="drag(event)";
	
	ctx.drawImage(img, posX, posY, width, height);	
}*/

    return {
        init: init
    };
}());

function calibration(x, y) {
	var cx = [1.0, 8.0, 10.0];
	var cy = [2.0, 5.0, 8.0];

	var sx = [4.0, 8.0, 12.0];
	var sy = [3.0, 8.0, 10.0];

	var sxdiff0 = sx[1] - sx[0];
	var sxdiff1 = sx[2] - sx[0];
	       
	var sydiff0 = sy[1] - sy[0];
	var sydiff1 = sy[2] - sy[0];

	var cxdiff0 = cx[1] - cx[0];
	var cxdiff1 = cx[2] - cx[0];

	var cydiff0 = cy[1] - cy[0];
	var cydiff1 = cy[2] - cy[0];
	
	var k =  (cydiff0/cxdiff0) - (cydiff1/cxdiff1);

	var b = (sxdiff0/cxdiff0 - sxdiff1/cxdiff1) / k;
	var d = (sydiff0/cydiff0 - sydiff1/cydiff1) / k;

	var a = (sxdiff0 - b*cydiff0) / cxdiff0;
	var c = (sydiff0 - d*cydiff0) / cxdiff0;

	var tx = sx[0] - (a*cx[0] + b*cy[0]);
	var ty = sy[0] - (c*cx[0] + d*cy[0]);
	
	var result = [[0.0, 0.0],[0.0, 0.0],[0.0, 0.0]];
	//result[3][2]

	result[0][0] = a;
	result[0][1] = c;

	result[1][0] = b;
	result[1][1] = d;

	result[2][0] = tx;
	result[2][1] = ty;

	/** TO USE CALIBRATION TRANSFORMS **/

	// Transform
	var calX = x * result[0][0] + y * result[0][1];
	var calY = x * result[1][0] + y * result[1][1];

	// Transpose
	calX += result[2][0];
	calY += result[2][1];
	
	var calXY = [calX, calY];
	//document.getElementById('message').innerHTML = 'calX: ' + calX + ', calY: ' + calY;

	return calXY;
}

function getDeviceID() {
	return deviceID;
}